angular.module('NmHr')
  .directive('myUpload', ['App', '$cordovaFileTransfer', '$cordovaCamera', '$cordovaImagePicker', 'Util',
    function (App, $cordovaFileTransfer, $cordovaCamera, $cordovaImagePicker, Util) {
      return {
        link: function (scope, ele, attr, ctrls) {
          var server = Util.getUploadPath();
          var filePath = "";

          ele.on('click', function () {
            var tmpPromise = null;
            App.ionicActionSheet.show({
              buttons: [{
                name: "camer",
                text: '拍照'
              }, {
                name: "photo",
                text: "从图片中选择"
              }],
              cancelText: '取消',
              cancel: function () {},
              buttonClicked: function (index, obj) {
                switch (obj.name) {
                  case "camer":
                    var camerOptions = {
                      quality: 50,
                      targetWidth: 1024,
                      destinationType: Camera.DestinationType.FILE_URI,
                      sourceType: Camera.PictureSourceType.CAMERA,
                      correctOrientation: true
                    }
                    tmpPromise = $cordovaCamera.getPicture(camerOptions)
                    break;
                  case "photo":
                    var pickerOptions = {
                      maximumImagesCount: 1,
                      width: 1024,
                      quality: 50,
                    };
                    tmpPromise = $cordovaImagePicker.getPictures(pickerOptions)
                    break;
                }

                upload(tmpPromise);
                return true;
              }
            })
          })
          var upload = function (promise) {
            App.q.when(promise).then(function (res) {
              if (!res) App.q.reject();
              filePath = isArray(res) ? encodeURI(res[0]) : res
              return $cordovaFileTransfer.upload(server, filePath)
            }).then(function (res) {

              var data = JSON.parse(res.response)
              scope.vm.createResource(data.result)
            }).catch(function (e) {
              console.log(e);
            })
          }
        }
      }
    }
  ])
  .directive('sms', [function () {
    return {
      template: '<button class="button" ng-disabled="!form.phoneNo.$valid || !smsOpt.isSend || $parent.vm.verify.phoneNoError" ng-click="sendCode()">{{smsOpt.isSend? "获取验证码": "重新发送(" + smsOpt.time +")"}}</button>',
      transclude: true,
      replace: true,
      restrict: 'E',
      controller: ['App', '$scope', '$element', '$attrs', '$sce', 'SmsToken',
        function (App, $scope, ele, attrs, $sce, SmsToken) {
          var $parent = $scope.$parent;
          var sendSmsBtn = ngJqLite(document.querySelector('.send-captcha'));
          $scope.smsOpt = {
            isSend: true,
            time: 30,
            count: 30
          };
          $scope.captchaInfo = {};
          $scope.valid = {
            captchaCode: false
          };

          //发送验证码
          $scope.sendCode = function () {
            $scope.smsOpt.isSend = false;
            SmsToken.requestCode({
              phoneNumber: $parent.vm.formModel.phoneNo,
            }).$promise.then(function (res) {
              if (res.token) {
                $parent.vm.formModel.tokenId = res.token.id;
                smsTimer();
              } else {
                $scope.smsOpt.isSend = true;
                errorAlert();
              }
            }).catch(function (error) {
              $scope.smsOpt.isSend = true;
              if (error.status == 429) {
                errorAlert();
              } else if (error.status == 423) {
                smsConfirm();
              }
            });
          };

          //短信计时器
          var smsTimer = function () {
            var timer = App.interval(function () {
              $scope.smsOpt.time--;
            }, 1000, $scope.smsOpt.count);

            timer.then(function () {
              $scope.smsOpt.time = $scope.smsOpt.count;
              $scope.smsOpt.isSend = true;
              App.interval.cancel(timer);
            });
          };

          //解除发送受限
          var smsConfirm = function () {
            App.ionPopup.confirm({
              cssClass: 'confirm-sms',
              title: '验证码发送超出次数',
              template: '<div class="sms-wrap">' +
                '<form role="form" class="form-horizontal" name="smsForm">' +
                '<div class="sub-title">' +
                '<p>请输入下方验证码后再次尝试</p>' +
                '</div>' +
                '<div class="sms-code">' +
                '<span ng-bind-html="captchaInfo.$$captcha"></span>' +
                '<button  ng-click="getCaptcha()" ng-disabled="valid.captchaCode">换一个</button>' +
                '</div>' +
                '<div class="sms-input">' +
                '<input type="text" name="captchaCode" placeholder="图形码" maxlength="4" ng-model="captchaInfo.captchaCode" ng-change="validateCaptcha()" ng-disabled="valid.captchaCode" ng-pattern="/^[a-zA-Z0-9]{4,6}$/" required>' +
                '<div class="icon-wrap">' +
                '<i class="icon ion-ios-checkmark col-succ" ng-if="smsForm.captchaCode.$valid && valid.captchaCode"></i>' +
                '</div>' +
                '</div>' +
                '</form>' +
                '</div>',
              scope: $scope,
              buttons: [{
                text: '取消',
                onTap: function (e) {
                  $scope.valid.captchaCode = true;
                  $scope.captchaInfo.captchaCode = "";
                }
              }, {
                text: '<b>提交</b>',
                type: 'btn-positive send-captcha',
                onTap: function (e) {
                  $scope.sendCode();
                }
              }]
            });

            App.timeout(function () {
              sendSmsBtn = ngJqLite(document.querySelector('.send-captcha'));
              sendSmsBtn.attr('disabled', ' ');
            }, 300);

            $scope.getCaptcha();
          };

          // 操作频繁提示
          var errorAlert = function () {
            App.ionPopup.alert({
              cssClass: 'ios-alert',
              title: "频繁操作",
              template: '您的操作过于频繁，</br>请休息一下再重新操作',
              okText: "确定",
              okType: "btn-assertive"
            });
          };

          //获取图片验证码
          $scope.getCaptcha = function () {
            SmsToken.requestCaptcha({
              phoneNumber: $parent.vm.formModel.phoneNo
            }).$promise.then(function (res) {
              $scope.captchaInfo.captchaId = res.id;
              $scope.captchaInfo.$$captcha = $sce.trustAsHtml(res.captcha);
            });
          };

          //校验图片验证码
          $scope.validateCaptcha = function () {
            if (!$scope.captchaInfo.captchaCode) return;

            SmsToken.validateCaptcha({
              captchaId: $scope.captchaInfo.captchaId,
              phoneNumber: $parent.vm.formModel.phoneNo,
              captchaCode: $scope.captchaInfo.captchaCode
            }).$promise.then(function (res) {
              $scope.valid.captchaCode = res.status;
              if (res.status) sendSmsBtn.removeAttr('disabled');
            });
          };
        }
      ],
      link: function (scope, ele, attr, ctrls) {}
    }
  }])
  .constant('uibButtonConfig', {
    activeClass: 'uib-active',
    toggleEvent: 'click'
  })
  .controller('UibButtonsController', ['uibButtonConfig', function (buttonConfig) {
    this.activeClass = buttonConfig.activeClass || 'active';
    this.toggleEvent = buttonConfig.toggleEvent || 'click';
  }])
  .directive('uibBtnRadio', ['$parse', function ($parse) {
    return {
      require: ['uibBtnRadio', 'ngModel'],
      controller: 'UibButtonsController',
      controllerAs: 'buttons',
      link: function (scope, element, attrs, ctrls) {
        var buttonsCtrl = ctrls[0],
          ngModelCtrl = ctrls[1];
        var uncheckableExpr = $parse(attrs.uibUncheckable);

        element.find('input').css({
          display: 'none'
        });

        //model -> UI
        ngModelCtrl.$render = function () {
          element.toggleClass(buttonsCtrl.activeClass, angular.equals(ngModelCtrl.$modelValue, scope.$eval(attrs.uibBtnRadio)));
        };

        //ui->model
        element.on(buttonsCtrl.toggleEvent, function () {
          if (attrs.disabled) {
            return;
          }

          var isActive = element.hasClass(buttonsCtrl.activeClass);

          if (!isActive || angular.isDefined(attrs.uncheckable)) {
            scope.$apply(function () {
              ngModelCtrl.$setViewValue(isActive ? null : scope.$eval(attrs.uibBtnRadio));
              ngModelCtrl.$render();
            });
          }
        });

        if (attrs.uibUncheckable) {
          scope.$watch(uncheckableExpr, function (uncheckable) {
            attrs.$set('uncheckable', uncheckable ? '' : undefined);
          });
        }
      }
    };
  }])
  .directive('uibBtnCheckbox', function () {
    return {
      require: ['uibBtnCheckbox', 'ngModel'],
      controller: 'UibButtonsController',
      controllerAs: 'button',
      link: function (scope, element, attrs, ctrls) {
        var buttonsCtrl = ctrls[0],
          ngModelCtrl = ctrls[1];

        element.find('input').css({
          display: 'none'
        });

        function getTrueValue() {
          return getCheckboxValue(attrs.btnCheckboxTrue, true);
        }

        function getFalseValue() {
          return getCheckboxValue(attrs.btnCheckboxFalse, false);
        }

        function getCheckboxValue(attribute, defaultValue) {
          return angular.isDefined(attribute) ? scope.$eval(attribute) : defaultValue;
        }

        //model -> UI
        ngModelCtrl.$render = function () {
          element.toggleClass(buttonsCtrl.activeClass, angular.equals(ngModelCtrl.$modelValue, getTrueValue()));
        };

        //ui->model
        element.on(buttonsCtrl.toggleEvent, function () {
          if (attrs.disabled) {
            return;
          }

          scope.$apply(function () {
            ngModelCtrl.$setViewValue(element.hasClass(buttonsCtrl.activeClass) ? getFalseValue() : getTrueValue());
            ngModelCtrl.$render();
          });
        });
      }
    };
  })
  .directive('imageGroup', [function () {
    return {
      controller: ['$scope', '$ionicModal', function (scope, $ionicModal) {
        var _self = this;
        _self.images = [];
        _self.addImage = function (imgItem) {
          this.images.push(imgItem)
        }
        _self.modal = null;

        $ionicModal.fromTemplateUrl('./tpls/modal/image/zoom.html', {
          scope: scope
        }).then(function (modal) {
          _self.modal = modal;
        })

        scope.$on('$destroy', function () {
          _self.modal = null;
          _self.images = [];
        });
      }]
    }
  }])
  .directive('imageItem', ['$ionicModal', function ($ionicModal) {
    return {
      require: '^imageGroup',
      link: function (scope, ele, attr, ctrl) {
        var imgUrl = scope.$eval(attr.imgUrl);
        scope.allImages = [];

        ele.on('click', function (e) {
          scope.images = ctrl.images;
          ctrl.modal.show();
        })

        ctrl.addImage(imgUrl)

      }
    }
  }])
  .directive('zoomImg', ['$ionicModal', '$ionicSlideBoxDelegate', '$ionicScrollDelegate', '$cacheFactory', function ($ionicModal, $ionicSlideBoxDelegate, $ionicScrollDelegate, $cacheFactory) {
    return {
      scope: {
        imgUrl: "@"
      },
      link: function (scope, ele, attr, ctrl) {
        scope.imgSrc = "";

        $ionicModal.fromTemplateUrl('./tpls/modal/image/zoom.html', {
          scope: scope
        }).then(function (modal) {
          scope.modal = modal;
        })

        scope.hideModal = function () {
          if (global.isIos) {
            scope.modal.hide();
          }
        }

        if (!scope.imgUrl) {
          attr.$observe('src', function (value) {
            scope.imgSrc = value
          })
        }

        ele.on('click', function (modal) {
          scope.modal.show()
        })

        scope.$on('$destroy', function () {
          scope.modal.remove();
        });
      }
    }
  }])
  .directive('openBrower', ['$cordovaInAppBrowser', function ($cordovaInAppBrowser) {
    return {
      scope: {
        options: "=",
        type: "@"
      },
      link: function (scope, ele, attrs, ctrl) {
        var src = ""
        var type = scope.type || "_system"
        ele.on('click', function () {
          src = attrs.href;
          $cordovaInAppBrowser.open(src, type, scope.options)
        })
      }
    }
  }])