/**
 * app常用服务 2016/11/04.
 */

angular.module('nmServices', [])
    .constant('NoAuthList', ['main.login', 'main.find', 'main.agreement'])
    .constant('App', {
        VERSION : '1482561783772'
    })
    //报错拦截器
    .factory('ErrorInterceptor', ['App', '$rootScope', 'localStorageService',
        function (App, $rootScope, localStorageService) {
            var count = 0
            var isXHR = function (data) {
                return data.url.indexOf('api') >= 0
            }
            return {
                'request': function (config) {
                    if (isXHR(config)) {
                        count++;
                        config.headers.Authorization = localStorageService.get('access_token');
                        App.timeout(function () {
                            if (count > 0) {
                                $rootScope.$broadcast('loaddingShow')
                            }
                        }, 300);
                    }
                    return config;
                },
                'requestError': function (rejection) {
                    if (isXHR(rejection)) {
                        count--
                        $rootScope.$broadcast('loaddingHide')
                    }
                    return App.q.reject(rejection);
                },
                'response': function (response) {
                    if (isXHR(response.config)) {
                        count--;
                        App.timeout(function () {
                            if (count <= 0) {
                                $rootScope.$broadcast('loaddingHide')
                            }
                        }, 200)
                    }
                    return response;
                },
                'responseError': function (rejection) {
                    var error = rejection.data.error;

                    if (!isXHR(rejection.config)) {
                        return App.q.reject(rejection);
                    }

                    count--;
                    $rootScope.$broadcast('loaddingHide');

                    if (error.status == 401) {
                        // localStorageService.remove('access_token');
                        // App.state.go("main.find");
                    } else if (error && error.message && error.status != 423 && error.status != 429) {
                        App.ionPopup.alert({
                            cssClass: 'ios-alert',
                            title: "错误提示",
                            template: error.message,
                            okText: "确定",
                            okType: "btn-assertive"
                        });
                    }


                    return App.q.reject(rejection);
                }
            };
        }
    ])
    .service('UserInfo', ['App', 'Util', function (App, Util) {
        var defer = App.q.defer();
        var base = Util.queryStore('base') || {};
        var employee = Util.queryStore('employee') || {};
        var enterprise = Util.queryStore('enterprise') || {};
        return {
            getEmployee: function () {
                return employee;
            },
            setEmployee: function (item) {
                employee = item;
                Util.saveStore('employee', employee);
            },
            getEnterprise: function () {
                return enterprise;
            },
            setEnterprise: function (item) {
                enterprise = item;
                Util.saveStore('enterprise', enterprise);
            },
            getBase: function () {
                return base;
            },
            setBase: function (item) {
                base = item;
                Util.saveStore('base', base);
                Util.saveStore('access_token', base.token);
            },
            isAuth: function () {
                var access_token = Util.queryStore('access_token');

                if (access_token) {
                    return true;
                } else {
                    return false;
                }
            },
            destroy: function () {
                Util.removeStore('base');
                Util.removeStore('employee');
                Util.removeStore('enterprise');
                Util.removeStore('access_token');
            }
        };
    }])
    .factory('Util', ['App', 'localStorageService', 'LoopBackResource',
        function (App, localStorageService, LoopBackResource) {
            return {
                getHostName: function () {
                    return location.hostname;
                },
                comfirmPopup: function (opt) {
                    App.ionPopup.confirm({
                        cssClass: 'popup-confirm',
                        template: opt.title,
                        buttons: [{
                            text: opt.leftText
                        }, {
                            text: "<b>" + opt.rigthText + "</b>",
                            type: 'btn-assertive',
                            onTap: function (e) {
                                opt.rightTap()
                            }
                        }]
                    });
                },
                comfirmSheet: function (opt) {
                    App.ionicActionSheet.show({
                        cssClass: 'sheet-confirm',
                        buttons: [{
                            text: opt.sureText
                        }],
                        cancelText: opt.cancelText,
                        cancel: function () {},
                        buttonClicked: function () {
                            opt.sureTap();
                            return true;
                        }
                    });
                },
                getImgPath: function () {
                    return LoopBackResource.getUrlBase() + "/osscontainers/default/download/"
                },
                getUploadPath: function () {
                    return LoopBackResource.getUrlBase() + "/osscontainers/default/upload/"
                },
                saveStore: function (key, value) {
                    localStorageService.set(key, value);
                },
                queryStore: function (key) {
                    return localStorageService.get(key);
                },
                removeStore: function (key) {
                    localStorageService.remove(key);
                },
            }
        }
    ])