angular.module('NmHr')
  .controller('ExpenseCtrl', ['$scope', 'App',
    function ($scope, App) {
      $scope.type = App.stateParams.type;
      $scope.subType = App.stateParams.subType;
    }
  ])
  .filter('getTypeValue', [function () {
    return function (value) {
      var map = {
        medical: 1,
        fertility: 2,
        injury: 3,
        ssTransfer: 4,
      }
      return map[value]
    }
  }])
  .filter('getSubTypeValue', [function () {
    return function (value, subValue) {
      var map = {
        medical: {
          normal: 11,
          illegal: 12,
          registered: 13,
          allow: 14
        },
        fertility: {
          only: 0
        },
        injury: {
          only: 0
        },
        ssTransfer: {
          medicalOut: 41,
          medicalIn: 42,
          pensionOut: 43,
          pensionIn: 44,
          pensionOutLocal: 45,
          pensionInLocal: 46,
        },
        ssTax : {
          only : 0
        }
      }
      return map[value][subValue]
    }
  }])
  .filter('getSubTypeTitle', [function () {
    return function (value, subValue) {
      var result = "";
      if (!value || !subValue) return
      var map = {
        medical: {
          normal: "内地就医的普通门诊费用报销",
          illegal: "未按规定转诊或登记",
          registered: "已办理常住内地就医备案的参保人",
          allow: "经核准转诊市外医院的报销"
        },
        fertility: {
          only: "生育报销"
        },
        injury: {
          only: '工伤详情'
        },
        ssTransfer: {
          medicalOut: "医疗保险关系转出",
          medicalIn: "医疗保险关系转入",
          pensionOut: "养老保险关系跨省转出",
          pensionIn: "养老保险关系跨省转入",
          pensionOutLocal: "养老保险关系省内转出",
          pensionInLocal: "养老保险关系省内转入",
        }
      }
      result = map[value][subValue] || "报销详情"
      return result;
    }
  }])
  .filter('getTypeTitle', [function () {
    return function (value) {
      var result = "";
      switch (value) {
        case 'medical':
          result = "医保报销"
          break;
        case 'fertility':
          result = "生育报销"
          break;
        case 'injury':
          result = "工伤报销"
          break;
        case 'ssTransfer':
          result = "社保转移"
          break;
        case 'ssTax':
          result = "社保补缴"
          break;
      }
      return result;
    }
  }])
  .filter('getTypeImg', [function () {
    return function (value) {
      var result = "./img/other/";
      switch (value) {
        case 'medical':
          result += "bg_medical_guide.png"
          break;
        case 'fertility':
          result += "bg_fertility_guide.png"
          break;
        case 'injury':
          result += "bg_injury_guide.png"
          break;
        case 'ssTransfer':
          result += "bg_transfer_guide.png"
          break;
        case 'ssTax':
          result += "bg_bujiao_guide.png"
          break;
      }
      return result;
    }
  }])
  .filter('medicalTypeText', [function () {
    //尾号处理
    return function (value) {
      if (!value) return
      var map = {
        '11': '内地就医的普通门诊费用报销',
        '12': '自行到市外就医的住院费用的报销',
        '13': '在备案医院住院费用报销',
        '14': '经核准转诊市外医院的报销',
        '41': '医疗保险关系转出',
        '42': '医疗保险关系转入',
        '43': '养老保险关系跨省转出',
        '44': '养老保险关系跨省转入',
        '45': '养老保险省内转出',
        '46': '养老保险省内转入'
      }
      return map[value];
    }
  }])